@@ -1,30 +1,46 @@
 pub mod defaults;
 pub mod fields_on_correct_type;
 pub mod fragments_on_composite_types;
+pub mod known_argument_names;
 pub mod known_fragment_names;
 pub mod known_type_names;
 pub mod leaf_field_selections;
 pub mod lone_anonymous_operation;
+pub mod no_fragments_cycle;
+pub mod no_undefined_variables;
 pub mod no_unused_fragments;
+pub mod no_unused_variables;
 pub mod overlapping_fields_can_be_merged;
+pub mod possible_fragment_spreads;
+pub mod provided_required_arguments;
 /// Utilities validating GraphQL documents/operations
 pub mod rule;
 pub mod single_field_subscriptions;
+pub mod unique_argument_names;
 pub mod unique_fragment_names;
 pub mod unique_operation_names;
+pub mod unique_variable_names;
 pub mod variables_are_input_types;
 
 pub use self::defaults::*;
 pub use self::fields_on_correct_type::*;
 pub use self::fragments_on_composite_types::*;
+pub use self::known_argument_names::*;
 pub use self::known_fragment_names::*;
 pub use self::known_type_names::*;
 pub use self::leaf_field_selections::*;
 pub use self::lone_anonymous_operation::*;
+pub use self::no_fragments_cycle::*;
+pub use self::no_undefined_variables::*;
 pub use self::no_unused_fragments::*;
+pub use self::no_unused_variables::*;
 pub use self::overlapping_fields_can_be_merged::*;
+pub use self::possible_fragment_spreads::*;
+pub use self::provided_required_arguments::*;
 pub use self::rule::*;
 pub use self::single_field_subscriptions::*;
+pub use self::unique_argument_names::*;
 pub use self::unique_fragment_names::*;
 pub use self::unique_operation_names::*;
+pub use self::unique_variable_names::*;
 pub use self::variables_are_input_types::*;
